containertools.Container
========================

.. inheritance-diagram:: abjad.tools.containertools.Container.Container.Container
   :private-bases:

.. autoclass:: abjad.tools.containertools.Container.Container.Container

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.contents_duration

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.duration_in_seconds

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.format

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.leaves

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.marks

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.music

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.override

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.parent

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.preprolated_duration

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.prolated_duration

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.prolation

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.set

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.spanners

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.is_parallel

Methods
-------

.. automethod:: abjad.tools.containertools.Container.Container.Container.append

.. automethod:: abjad.tools.containertools.Container.Container.Container.extend

.. automethod:: abjad.tools.containertools.Container.Container.Container.index

.. automethod:: abjad.tools.containertools.Container.Container.Container.insert

.. automethod:: abjad.tools.containertools.Container.Container.Container.pop

.. automethod:: abjad.tools.containertools.Container.Container.Container.remove

Special Methods
---------------

.. automethod:: abjad.tools.containertools.Container.Container.Container.__add__

.. automethod:: abjad.tools.containertools.Container.Container.Container.__contains__

.. automethod:: abjad.tools.containertools.Container.Container.Container.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.containertools.Container.Container.Container.__delitem__

.. automethod:: abjad.tools.containertools.Container.Container.Container.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.containertools.Container.Container.Container.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.containertools.Container.Container.Container.__getitem__

.. automethod:: abjad.tools.containertools.Container.Container.Container.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.containertools.Container.Container.Container.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.containertools.Container.Container.Container.__iadd__

.. automethod:: abjad.tools.containertools.Container.Container.Container.__imul__

.. automethod:: abjad.tools.containertools.Container.Container.Container.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.containertools.Container.Container.Container.__len__

.. automethod:: abjad.tools.containertools.Container.Container.Container.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.containertools.Container.Container.Container.__mul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.containertools.Container.Container.Container.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.containertools.Container.Container.Container.__radd__

.. automethod:: abjad.tools.containertools.Container.Container.Container.__repr__

.. automethod:: abjad.tools.containertools.Container.Container.Container.__rmul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.containertools.Container.Container.Container.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.containertools.Container.Container.Container.__setitem__

.. automethod:: abjad.tools.containertools.Container.Container.Container.__str__

   .. note:: Inherited from `__builtin__.object`
